pub enum VectorError {
EmptyVectorError(String),
TryFromSliceError(String),
TryFromVecError(String),
ValueError(String),
}Expand description
Errors that occur while working with crate::types::vector::Vector
Variants
EmptyVectorError(String)
Occurs when an operation that requires data in a crate::types::vector::Vector is
requested with an empty crate::types::vector::Vector
TryFromSliceError(String)
Occurs when there is invalid data during an attempt to convert
from slice data.
TryFromVecError(String)
Occurs when there is invalid data during an attempt to convert
from Vec data.
ValueError(String)
ValueError occurs when an invalid value is used in an operation