Enum vectora::errors::VectorError[][src]

pub enum VectorError {
    TryFromSliceError(String),
    TryFromVecError(String),
    ValueError(String),
}
Errors that occur while working with crate::types::vector::Vector

Variants

TryFromSliceError(String)

Tuple Fields

0: String

Occurs when there is invalid data during an attempt to convert from slice data.

TryFromVecError(String)

Tuple Fields

0: String

Occurs when there is invalid data during an attempt to convert from Vec data.

ValueError(String)

Tuple Fields

0: String

ValueError occurs when an invalid value is used in an operation